@@ -499,7 +499,7 @@ void cb_206_new()
 	clear_206_form();
 	clear_header();
 	def_206_filename = ICS_msg_dir;
-	def_206_filename.append("new"F206_EXT);
+	def_206_filename.append("new").append(F206_EXT);
 	show_filename(def_206_filename);
 	using_ics206_template = false;
 }
@@ -550,7 +550,8 @@ void cb_206_wrap_export()
 	}
 	update_206fields();
 
-	if (base_206_filename == "new"F206_EXT || base_206_filename == "default"F206_EXT)
+	if (base_206_filename == string("new").append(F206_EXT) ||
+		base_206_filename == string("default").append(F206_EXT) )
 		if (!cb_206_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -583,7 +584,8 @@ void cb_206_wrap_autosend()
 	}
 	update_206fields();
 
-	if (base_206_filename == "new"F206_EXT || base_206_filename == "default"F206_EXT)
+	if (base_206_filename == string("new").append(F206_EXT) ||
+		base_206_filename == string("default").append(F206_EXT) )
 		if (!cb_206_save_as()) return;
 
 	update_header(FROM);
@@ -601,7 +603,7 @@ void cb_206_load_template()
 	string def_206_filename = def_206_TemplateName;
 	const char *p = FSEL::select(
 			"Open template file",
-			"Template file\t*"T206_EXT,
+			string("Template file\t*").append(T206_EXT).c_str(),
 			def_206_filename.c_str());
 	if (p) {
 		clear_206_form();
@@ -621,7 +623,7 @@ void cb_206_save_template()
 	string def_206_filename = def_206_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"T206_EXT,
+			string("Template file\t*").append(T206_EXT).c_str(),
 			def_206_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -636,7 +638,7 @@ void cb_206_save_as_template()
 	string def_206_filename = def_206_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"T206_EXT,
+			string("Template file\t*").append(T206_EXT).c_str(),
 			def_206_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -655,8 +657,10 @@ void cb_206_save_as_template()
 
 void cb_206_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "ICS-206\t*"F206_EXT,
-					def_206_filename.c_str());
+	const char *p = FSEL::select(
+			_("Open data file"),
+			string("ICS-206\t*").append(F206_EXT).c_str(),
+			def_206_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	clear_206_form();
@@ -688,24 +692,15 @@ bool cb_206_save_as()
 	} else
 		newfilename = def_206_filename;
 
-	p = FSEL::saveas(_("Save data file"), "ICS-206\t*"F206_EXT,
-					newfilename.c_str());
+	p = FSEL::saveas(
+			_("Save data file"),
+			string("ICS-206\t*").append(F206_EXT).c_str(),
+			newfilename.c_str());
 
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
 
-	if (progStatus.sernbr_fname) {
-		string haystack = p;
-		if (haystack.find(newfilename) != string::npos) {
-			int n = atoi(progStatus.sernbr.c_str());
-			n++;
-			char szn[10];
-			snprintf(szn, sizeof(szn), "%d", n);
-			progStatus.sernbr = szn;
-			txt_sernbr->value(szn);
-			txt_sernbr->redraw();
-		}
-	}
+	if (progStatus.sernbr_fname) update_sernbr();
 
 	const char *pext = fl_filename_ext(p);
 	def_206_filename = p;
@@ -725,8 +720,8 @@ bool cb_206_save_as()
 
 void cb_206_save()
 {
-	if (base_206_filename == "new"F206_EXT || 
-		base_206_filename == "default"F206_EXT ||
+	if (base_206_filename == string("new").append(F206_EXT) || 
+		base_206_filename == string("default").append(F206_EXT) ||
 		using_ics206_template == true) {
 		cb_206_save_as();
 		return;
