@@ -22,6 +22,7 @@
 #define UTIL_H
 
 #include <string>
+#include "config.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -126,13 +127,13 @@ extern "C" {
 const__ uint32_t ceil2(uint32_t n);
 const__ uint32_t floor2(uint32_t n);
 
-//#if !HAVE_STRCASESTR
-//char* strcasestr(const char* haystack, const char* needle);
-//#endif
+#if !HAVE_STRCASESTR
+char* strcasestr(const char* haystack, const char* needle);
+#endif
 
-//#if !HAVE_STRLCPY
-//size_t strlcpy(char* dest, const char* src, size_t size);
-//#endif
+#if !HAVE_STRLCPY
+size_t strlcpy(char* dest, const char* src, size_t size);
+#endif
 
 int set_cloexec(int fd, unsigned char v);
 int set_nonblock(int fd, unsigned char v);
