@@ -567,7 +567,7 @@ void cb_severe_wx_new()
 	clear_severe_wx_form();
 	clear_header();
 	def_severe_wx_filename = ICS_msg_dir;
-	def_severe_wx_filename.append("new"FSWX_EXT);
+	def_severe_wx_filename.append("new").append(FSWX_EXT);
 	show_filename(def_severe_wx_filename);
 	using_severe_wx_template = false;
 }
@@ -618,7 +618,8 @@ void cb_severe_wx_wrap_export()
 	}
 	update_severe_wxfields();
 
-	if (base_severe_wx_filename == "new"FSWX_EXT || base_severe_wx_filename == "default"FSWX_EXT)
+	if (base_severe_wx_filename == string("new").append(FSWX_EXT) ||
+		base_severe_wx_filename == string("default").append(FSWX_EXT) )
 		if (!cb_severe_wx_save_as()) return;
 
 	string wrapfilename = WRAP_send_dir;
@@ -652,7 +653,8 @@ void cb_severe_wx_wrap_autosend()
 	}
 	update_severe_wxfields();
 
-	if (base_severe_wx_filename == "new"FSWX_EXT || base_severe_wx_filename == "default"FSWX_EXT)
+	if (base_severe_wx_filename == string("new").append(FSWX_EXT) ||
+		base_severe_wx_filename == string("default").append(FSWX_EXT) )
 		if (!cb_severe_wx_save_as()) return;
 
 	update_header(FROM);
@@ -670,7 +672,7 @@ void cb_severe_wx_load_template()
 	string def_severe_wx_filename = def_severe_wx_TemplateName;
 	const char *p = FSEL::select(
 			"Open template file",
-			"Template file\t*"TSWX_EXT,
+			string("Template file\t*").append(TSWX_EXT).c_str(),
 			def_severe_wx_filename.c_str());
 	if (p) {
 		clear_severe_wx_form();
@@ -690,7 +692,7 @@ void cb_severe_wx_save_template()
 	string def_severe_wx_filename = def_severe_wx_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save template file",
-			"Template file\t*"TSWX_EXT,
+			string("Template file\t*").append(TSWX_EXT).c_str(),
 			def_severe_wx_filename.c_str());
 	if (p) {
 		update_header(CHANGED);
@@ -706,7 +708,7 @@ void cb_severe_wx_save_as_template()
 	string def_severe_wx_filename = def_severe_wx_TemplateName;
 	const char *p = FSEL::saveas(
 			"Save as template file",
-			"Template file\t*"TSWX_EXT,
+			string("Template file\t*").append(TSWX_EXT).c_str(),
 			def_severe_wx_filename.c_str());
 	if (p) {
 		const char *pext = fl_filename_ext(p);
@@ -728,8 +730,10 @@ void cb_severe_wx_save_as_template()
 
 void cb_severe_wx_open()
 {
-	const char *p = FSEL::select(_("Open data file"), "ICS-severe_wx\t*"FSWX_EXT,
-					def_severe_wx_filename.c_str());
+	const char *p = FSEL::select(
+			_("Open data file"),
+			string("ICS-severe_wx\t*").append(FSWX_EXT).c_str(),
+			def_severe_wx_filename.c_str());
 	if (!p) return;
 	if (strlen(p) == 0) return;
 	clear_severe_wx_form();
@@ -762,24 +766,15 @@ bool cb_severe_wx_save_as()
 	} else
 		newfilename = def_severe_wx_filename;
 
-	p = FSEL::saveas(_("Save data file"), "ICS-severe_wx\t*"FSWX_EXT,
-					newfilename.c_str());
+	p = FSEL::saveas(
+			_("Save data file"),
+			string("ICS-severe_wx\t*").append(FSWX_EXT).c_str(),
+			newfilename.c_str());
 
 	if (!p) return false;
 	if (strlen(p) == 0) return false;
 
-	if (progStatus.sernbr_fname) {
-		string haystack = p;
-		if (haystack.find(newfilename) != string::npos) {
-			int n = atoi(progStatus.sernbr.c_str());
-			n++;
-			char szn[10];
-			snprintf(szn, sizeof(szn), "%d", n);
-			progStatus.sernbr = szn;
-			txt_sernbr->value(szn);
-			txt_sernbr->redraw();
-		}
-	}
+	if (progStatus.sernbr_fname) update_sernbr();
 
 	const char *pext = fl_filename_ext(p);
 	def_severe_wx_filename = p;
@@ -800,8 +795,8 @@ bool cb_severe_wx_save_as()
 
 void cb_severe_wx_save()
 {
-	if (base_severe_wx_filename == "new"FSWX_EXT || 
-		base_severe_wx_filename == "default"FSWX_EXT ||
+	if (base_severe_wx_filename == string("new").append(FSWX_EXT) || 
+		base_severe_wx_filename == string("default").append(FSWX_EXT) ||
 		using_severe_wx_template == true) {
 		cb_severe_wx_save_as();
 		return;
